#
# spec file for package python-cramjam
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Adjust the version in _service and use `rm -rf pyrus-cramjam; osc service runall` in order to update
Name:           python-cramjam
Version:        2.6.2
Release:        1.8
Summary:        Thin Python bindings to de/compression algorithms in Rust
License:        MIT
URL:            https://github.com/milesgranger/pyrus-cramjam
Source:         pyrus-cramjam-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        cargo_config
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module maturin >= 0.13}
BuildRequires:  %{python_module pip}
BuildRequires:  cargo-packaging
BuildRequires:  python-rpm-macros
# SECTION test dependencies
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  fdupes
%python_subpackages

%description
Extremely thin Python bindings to de/compression algorithms in Rust.
Allows for using algorithms such as Snappy, without any system dependencies.

%prep
%setup -q -n pyrus-cramjam-%{version} -a1
cp %{SOURCE2} .cargo/config

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch --ignore benchmarks

%files %{python_files}
%license LICENSE
%{python_sitearch}/cramjam
%{python_sitearch}/cramjam-%{version}.dist-info

%changelog
* Fri Jan 13 2023 Ben Greiner <code@bnavigator.de>
- Update to v2.6.2
  * Bump pyo3, numpy and expand pyproject.toml by @milesgranger in
    [#90]
- Updated crate fixes bzip2 < 0.4.4 vulnerability
  * boo#1207039, CVE-2023-22895
* Sat Oct 29 2022 Ben Greiner <code@bnavigator.de>
- Update to v2.6.1
  * Switch brotli2 -> brotli crate by @milesgranger in #87
* Fri Oct 28 2022 Ben Greiner <code@bnavigator.de>
- Update to v2.6.0
  * Update to pyo3 0.16 by @messense in #78
  * Update dependencies and simplify CI by @messense in #79
  * Support Lz4 de/compress_block_into functions by @milesgranger
    in #80
  * Upgrade maturin to 0.13.0 by @messense in #81
  * Integration tests, benchmark updates, subclass Buffer by
    @milesgranger in #83
  * Bump lz4-sys from 1.9.3 to 1.9.4 by @dependabot in #84
  * Add Python 3.11 by @milesgranger in #85
- Release v2.5.0
  * Incorporate property-based testing by @milesgranger in #69
  * Support bzip2 by @milesgranger in #70
- Release  v2.4.0
  * This release comes with streaming compression support for all
    variants. And updates Gzip compression variant to support
    properly decoding input which has multiple streams, as is the
    default with std gzip lib. This release does not alter any of
    the existing APIs.
  * Support compressed gzip multistream (#64) b9cfa13
  * Support Compressor for each variant (#64) 8ecb0fa
  * Support .flush for Compressor (#68) 4b92e42
  * Add official OSI name in the license metadata (#66) 446a671
* Tue Sep 28 2021 William Brown <william.brown@suse.com>
- Replace rust-packaging with cargo-packaging
* Mon Jul 19 2021 Ben Greiner <code@bnavigator.de>
- Update to 2.3.2
  * no core library code changes
- Update filelist due to updated setuptools: not a single .so but
  a full module directory now.
- run cargo crate service: update vendored rust crates
- re-activate cargo audit service
  * gh#openSUSE/obs-service-cargo_audit#1 is fixed
* Tue May 18 2021 Ben Greiner <code@bnavigator.de>
- initial specfile for 2.3.1
- new requirement of python-fastparquet 0.6
- use rust cargo crate vendoring following the how-to from
  https://fy.blackhats.net.au/blog/html/2021/02/15/getting_started_packaging_a_rust_cli_tool_in_suse_obs.html
